#!/bin/sh
# Bryant Hansen

ME="$(basename "$0")"
USAGE="$ME"

CRONTAB=/etc/crontab
CRON_BIN=upload_logfiles.sh
CONF_FILE="/etc/logfile_uploader.conf"

unset FAIL


DebugMessage() {
    local LOG_RECORD_HEADER="`date "+%Y%m%d_%H%M%S"` (${ME}):"
    echo "${LOG_RECORD_HEADER} $*" >&2
}


if [[ ! -f "$CONF_FILE" ]] ; then
    DebugMessage "ERROR: configuration file $CONF_FILE not found."
	DebugMessage "verify installation failure"
    exit 2
fi
. "$CONF_FILE"

cron_entry="$(cat "$CRONTAB" | sed "s/\#.*$//" | grep "$CRON_BIN")"
if [[ ! "$cron_entry" ]] ; then
	DebugMessage "ERROR: crontab entry not found."
	DebugMessage "no instance of $CRON_BIN in $CRONTAB"
	DebugMessage "verify installation failure"
	exit 3
fi

cron_path="$(cat "$CRONTAB" | sed "s/\#.*$//" | grep "PATH=")"
if [[ ! "$cron_path" ]] ; then
	DebugMessage "WARNING: PATH not found in crontab."
else
	# DebugMessage "# cron PATH: $cron_path"
	# DebugMessage "# PATH(orig): $PATH"
	export "$cron_path"
	# DebugMessage "# PATH(new): $PATH"
fi

if ! which "$CRON_BIN" > /dev/null 2>&1 ; then
	DebugMessage "ERROR: top-level binary $CRON_BIN not found in PATH."
	DebugMessage "verify installation failure"
	exit 4
fi

SED_REMOVE_COMMENTS='s/\#.*$//'
SED_DELETE_BLANK_LINES='/^[ \t]*$/d'

KNOWN_HOSTS_FILE=/home/root/.ssh/known_hosts
if ! grep "^dsapps.aizo.com ssh-rsa.*$" $KNOWN_HOSTS_FILE > /dev/null 2>&1 ; then
	DebugMessage "ERROR: dsapps known_host key does not exist in KNOWN_HOSTS_FILE $KNOWN_HOSTS_FILE"
	DebugMessage "verify installation failure"
	exit 7
fi

USER=$(get_mac_address.sh)
if [[ ! "$USER" ]] ; then
	DebugMessage "ERROR: failed to get MAC addressed (used for username login to server)"
	DebugMessage "verify installation failure"
	exit 8
fi
if [[ ! "${USER%%[0-9]*}" ]] ; then
    DebugMessage "$ME WARNING: MAC address does not begin with a letter.  Modifying registration name from $USER to m_${USER}"
    USER="m_${USER}"
fi
KEYFILE=/home/root/.ssh/${USER}.key

# verify that the key file exists
if [[ ! -f "$KEYFILE" ]] ; then
	DebugMessage "ERROR: no access to account on server"
	DebugMessage "verify installation failure"
	exit 9
fi

# verify that ssh is functioning
DebugMessage "checking for ssh connectability to ${SERVER}..."
if ! ssh -y $SSH_OPTS -i $KEYFILE $USER@$SERVER ls -al /home/$USER > /dev/null ; then
	DebugMessage "ERROR: no access to account on server"
	DebugMessage "verify installation failure"
	exit 10
else
	DebugMessage "ssh connection succeeded"
fi

# verify that we have access to the repository
DebugMessage "checking for existence of repository on ${SERVER}..."
if ! ssh -y $SSH_OPTS -i $KEYFILE $USER@$SERVER ls -al /var/log/digitalSTROM/$USER > /dev/null ; then
	DebugMessage "ERROR: no access to repository on server"
	DebugMessage "verify installation failure"
	exit 11
else
	DebugMessage "repository exists on $SERVER"
fi

DebugMessage "The upload_logfiles package appears to be correctly-installed."
exit 0
